@@ -66,7 +66,7 @@ def read_im_to_array(image, xres, yres, color=False, prepipe=None):
 def img_2_stats(img, res=None, omegas=None, cos=None, scale=179, hblur=False):
     """read image and return Ev and luminance ratio"""
     if hblur:
-        imarray = read_im_to_array(img, res, res, prepipe='humanblur_nh.csh {}')
+        imarray = read_im_to_array(img, res, res, prepipe='humanblur.csh {}')
     else:
         imarray = read_im_to_array(img, res, res)
     wlum = imarray * omegas * scale
